@@ -150,8 +150,8 @@ class Accountant:
     def create_book(account_id: str, ledger_host):
         log.info("---------New_ledger-------------")
         ledger = LedgerClient(ledger_host=ledger_host)
-        block_book_id = ledger.create_book(name=f"{account_id}_block_book", min_balance=0)
-        main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance=0)
+        block_book_id = ledger.create_book(name=f"{account_id}_block_book", min_balance="0")
+        main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance="0")
         new_books = {
             'main_balance': {'name': main_book_id['name'],
                              'id': main_book_id['id']},
